@@ -17,17 +17,18 @@ q_emiss <- c(4,2)
 gamma <- matrix(c(0.8, 0.1, 0.1,
                   0.2, 0.6, 0.2,
                   0.1, 0.2, 0.7), ncol = m, byrow = TRUE)
-emiss_distr <- list(matrix(c(0.5, 0.5, 0.0, 0.0,
-                        0.1, 0.1, 0.8, 0.0,
-                        0.1, 0.1, 0.2, 0.6), nrow = m, ncol = q_emiss[1], byrow = TRUE),
+emiss_distr <- list(matrix(c(0.45, 0.45, 0.05, 0.05,
+                             0.1, 0.05, 0.8, 0.05,
+                             0.1, 0.1, 0.2, 0.6), nrow = m, ncol = q_emiss[1], byrow = TRUE),
                     matrix(c(0.7, 0.3,
                              0.9, 0.1,
                              0.8, 0.2), nrow = m, ncol = q_emiss[2], byrow = TRUE)
-                )
+)
 
 set.seed(4231)
 data_sim <- sim_mHMM(n_t = n_t, n = n, gen = list(m = m, n_dep = n_dep, q_emiss = q_emiss), gamma = gamma,
                   emiss_distr = emiss_distr, var_gamma = .5, var_emiss = c(.5, 0.5))
+
 colnames(data_sim$obs) <- c("subj", "output_1", "output_2")
 
 # Fit the mHMM on 2 dep variable data
@@ -144,16 +145,16 @@ test_that("print mHMM", {
   # 2 dependent var, no covariates
   expect_output(print(out_2st_simb), paste("Number of subjects:", n))
   expect_output(print(out_2st_simb), paste(J, "iterations"))
-  expect_output(print(out_2st_simb), paste("likelihood over all subjects:", -167))
-  expect_output(print(out_2st_simb), paste("AIC over all subjects:", 371))
+  expect_output(print(out_2st_simb), paste("likelihood over all subjects:", -170))
+  expect_output(print(out_2st_simb), paste("AIC over all subjects:", 377))
   expect_output(print(out_2st_simb), paste("states used:", m))
   expect_output(print(out_2st_simb), paste("dependent variables used:", n_dep))
 })
 
 test_that("summary mHMM", {
   # 2 dependent var, no covariates
-  expect_output(summary(out_2st_simb), "From state 1      0.656      0.162      0.182")
-  expect_output(summary(out_2st_simb), "From state 3      0.168      0.244      0.589")
+  expect_output(summary(out_2st_simb), "From state 1      0.762      0.138      0.100")
+  expect_output(summary(out_2st_simb), "From state 3      0.095      0.324      0.581")
   expect_output(summary(out_2st_simb), "output_1")
   expect_output(summary(out_2st_simb), "output_2")
 })
@@ -162,14 +163,17 @@ test_that("summary mHMM", {
 test_that("output PD_subj", {
   # test output dimensions
   expect_equal(length(out_2st_simb$PD_subj), n)
-  expect_equal(dim(out_2st_simb$PD_subj[[1]]), c(J, m*q_emiss[1] + m*q_emiss[2] + m * m + 1))
-  expect_equal(dim(out_2st_simb$PD_subj[[1]]), dim(out_2st_simb$PD_subj[[n]]))
+  expect_equal(dim(out_2st_simb$PD_subj[[1]]$trans_prob), c(J, m * m ))
+  expect_equal(dim(out_2st_simb$PD_subj[[1]]$cat_emiss), c(J, sum(m*q_emiss)))
+  expect_equal(dim(out_2st_simb$PD_subj[[1]]$log_likl), c(J, 1))
+  expect_equal(length(out_2st_simb$PD_subj[[1]]), length(out_2st_simb$PD_subj[[n]]))
   # start values
-  expect_equal(as.vector(out_2st_simb$PD_subj[[2]][1,]), c(as.vector(t(emiss_distr[[1]])),
-                                                           as.vector(t(emiss_distr[[2]])),as.vector(t(gamma)), NA))
+  expect_equal(as.vector(out_2st_simb$PD_subj[[2]]$cat_emiss[1,]), c(as.vector(t(emiss_distr[[1]])),
+                                                           as.vector(t(emiss_distr[[2]]))))
+  expect_equal(as.vector(out_2st_simb$PD_subj[[2]]$trans_prob[1,]), as.vector(t(gamma)))
   # calculations
-  expect_equal(as.numeric(out_2st_simb$PD_subj[[2]][10,(m*q_emiss[1] + 2)]), 0.2119, tolerance=1e-4)
-  expect_equal(as.numeric(out_2st_simb$PD_subj[[2]][10,( m*q_emiss[1] + m*q_emiss[2] + m * m + 1)]), -175.6027, tolerance=1e-4)
+  expect_equal(as.numeric(out_2st_simb$PD_subj[[2]]$cat_emiss[10,(m*q_emiss[1] + 2)]), 0.4066, tolerance=1e-4)
+  expect_equal(as.numeric(out_2st_simb$PD_subj[[2]]$log_likl[10,1]), -181.6811 , tolerance=1e-4)
 })
 
 test_that("output emis_cov_bar", {
@@ -183,8 +187,8 @@ test_that("output emis_cov_bar", {
   expect_equal(dim(out_2st_sim_cov4$emiss_cov_bar[[1]]), c(J, m * (q_emiss[1] - 1)))
   expect_match(out_2st_sim_cov4$emiss_cov_bar[[2]], "predict the emission probabilities")
   # test calcultations
-  expect_equal(as.numeric(out_2st_sim_cov1$emiss_cov_bar[[1]][11,  m * (q_emiss[1] - 1)]), -0.03732154, tolerance=1e-4)
-  expect_equal(as.numeric(out_2st_sim_cov1$emiss_cov_bar[[2]][11,  m * (q_emiss[2] - 1)]), -0.1561908, tolerance=1e-4)
+  expect_equal(as.numeric(out_2st_sim_cov1$emiss_cov_bar[[1]][11,  m * (q_emiss[1] - 1)]), -1.129246 , tolerance=1e-4)
+  expect_equal(as.numeric(out_2st_sim_cov1$emiss_cov_bar[[2]][11,  m * (q_emiss[2] - 1)]), 0.07090971 , tolerance=1e-4)
 })
 
 test_that("output emiss_int_bar", {
@@ -193,8 +197,8 @@ test_that("output emiss_int_bar", {
   expect_equal(dim(out_2st_simb$emiss_int_bar[[2]]), c(J, m * (q_emiss[2] - 1)))
   expect_equal(dim(out_2st_sim_cov1$emiss_int_bar[[1]]), c(J, m * (q_emiss[1] - 1)))
   # calculations
-  expect_equal(as.numeric(out_2st_simb$emiss_int_bar[[1]][10,m * (q_emiss[1] - 1)]), 1.547461, tolerance=1e-4)
-  expect_equal(as.numeric(out_2st_simb$emiss_int_bar[[2]][11,m * (q_emiss[2] - 1) - 1]), -1.519971, tolerance=1e-4)
+  expect_equal(as.numeric(out_2st_simb$emiss_int_bar[[1]][10,m * (q_emiss[1] - 1)]), 1.03869 , tolerance=1e-4)
+  expect_equal(as.numeric(out_2st_simb$emiss_int_bar[[2]][11,m * (q_emiss[2] - 1) - 1]), -1.274551 , tolerance=1e-4)
 })
 
 test_that("output emiss_int_subj", {
@@ -203,7 +207,7 @@ test_that("output emiss_int_subj", {
   expect_equal(dim(out_2st_simb$emiss_int_subj[[1]][[1]]), dim(out_2st_simb$emiss_int_subj[[n]][[1]]))
   expect_equal(dim(out_2st_simb$emiss_int_subj[[1]][[2]]), c(J, m * (q_emiss[2] - 1)))
   # calculations
-  expect_equal(as.numeric(out_2st_simb$emiss_int_subj[[1]][[1]][2,1]), -0.8574116, tolerance = 1e-4)
+  expect_equal(as.numeric(out_2st_simb$emiss_int_subj[[1]][[1]][2,1]),  -0.8649858 , tolerance = 1e-4)
 })
 
 test_that("output emiss_naccept", {
@@ -212,7 +216,7 @@ test_that("output emiss_naccept", {
   expect_equal(dim(out_2st_simb$emiss_naccept[[1]]), c(J-1, m))
   expect_equal(dim(out_2st_simb$emiss_naccept[[2]]), c(J-1, m))
   # calculations
-  expect_equal(out_2st_simb$emiss_naccept[[1]][9,2], 6)
+  expect_equal(out_2st_simb$emiss_naccept[[1]][9,2], 3)
   expect_equal(out_2st_simb$emiss_naccept[[2]][10,3], 3)
 })
 
@@ -224,8 +228,8 @@ test_that("output emiss_prob_bar", {
   expect_equal(as.vector(out_2st_simb$emiss_prob_bar[[1]][1,]), as.vector(t(emiss_distr[[1]])))
   expect_equal(as.vector(out_2st_simb$emiss_prob_bar[[2]][1,]), as.vector(t(emiss_distr[[2]])))
   # calculations
-  expect_equal(as.numeric(out_2st_simb$emiss_prob_bar[[1]][11, q_emiss[1]]),  0.07300545, tolerance = 1e-4)
-  expect_equal(as.numeric(out_2st_sim_cov1$emiss_prob_bar[[2]][10, q_emiss[2]]),0.3836453, tolerance = 1e-4)
+  expect_equal(as.numeric(out_2st_simb$emiss_prob_bar[[1]][11, q_emiss[1]]),  0.08674569 , tolerance = 1e-4)
+  expect_equal(as.numeric(out_2st_sim_cov1$emiss_prob_bar[[2]][10, q_emiss[2]]),0.336074, tolerance = 1e-4)
 })
 
 test_that("output gamma_cov_bar", {
@@ -236,7 +240,7 @@ test_that("output gamma_cov_bar", {
   expect_equal(dim(out_2st_sim_cov3$gamma_cov_bar), c(J, m * (m-1)))
   expect_match(out_2st_sim_cov4$gamma_cov_bar, "predict the transition probability")
   # calculations
-  expect_equal(as.numeric(out_2st_sim_cov2$gamma_cov_bar[10, m * (m-1) - 1]), 0.64298, tolerance = 1e-4)
+  expect_equal(as.numeric(out_2st_sim_cov2$gamma_cov_bar[10, m * (m-1) - 1]), 0.2785782 , tolerance = 1e-4)
 })
 
 test_that("output gamma_int_bar", {
@@ -244,7 +248,7 @@ test_that("output gamma_int_bar", {
   expect_equal(dim(out_2st_simb$gamma_int_bar), c(J, m * (m - 1)))
   expect_equal(dim(out_2st_sim_cov2$gamma_int_bar), c(J, m * (m - 1)))
   # calculations
-  expect_equal(as.numeric(out_2st_sim_cov2$gamma_int_bar[11, m - 1]), -1.643041, tolerance = 1e-4)
+  expect_equal(as.numeric(out_2st_sim_cov2$gamma_int_bar[11, m - 1]), -1.69139 , tolerance = 1e-4)
 })
 
 
@@ -254,14 +258,14 @@ test_that("output gamma_int_subj", {
   expect_equal(dim(out_2st_simb$gamma_int_subj[[1]]), dim(out_2st_simb$gamma_int_subj[[n]]))
   expect_equal(dim(out_2st_simb$gamma_int_subj[[1]]), c(J, m * (m - 1)))
   # calculations
-  expect_equal(as.numeric(out_2st_simb$gamma_int_subj[[1]][11, 2 * (m-1)]), 1.131609, tolerance = 1e-4)
+  expect_equal(as.numeric(out_2st_simb$gamma_int_subj[[1]][11, 2 * (m-1)]), 0.8804161 , tolerance = 1e-4)
 })
 
 test_that("output gamma_naccept", {
   # test output dimensions
   expect_equal(dim(out_2st_simb$gamma_naccept), c((J-1), m))
   # calculations
-  expect_equal(out_2st_simb$gamma_naccept[8,3], 0)
+  expect_equal(out_2st_simb$gamma_naccept[8,3], 5)
 })
 
 test_that("output gamma_prob_bar", {
@@ -270,22 +274,23 @@ test_that("output gamma_prob_bar", {
   # start values
   expect_equal(as.vector(out_2st_simb$gamma_prob_bar[1,]), as.vector(t(gamma)))
   # calculations
-  expect_equal(as.numeric(out_2st_simb$gamma_prob_bar[11,1]),0.648415, tolerance = 1e-4)
-  expect_equal(as.numeric(out_2st_simb$gamma_prob_bar[10,8]), 0.2822081, tolerance = 1e-4)
+  expect_equal(as.numeric(out_2st_simb$gamma_prob_bar[11,1]),0.8075333 , tolerance = 1e-4)
+  expect_equal(as.numeric(out_2st_simb$gamma_prob_bar[10,8]), 0.3415242, tolerance = 1e-4)
 })
 
 test_that("output input", {
   # test output dimensions
-  expect_equal(length(out_2st_simb$input), 8)
+  expect_equal(length(out_2st_simb$input), 9)
   # test correct output
-  expect_equal(out_2st_simb$input[[1]], m)
-  expect_equal(out_2st_simb$input[[2]], n_dep)
-  expect_equal(out_2st_simb$input[[3]], q_emiss)
-  expect_equal(out_2st_simb$input[[4]], J)
-  expect_equal(out_2st_simb$input[[5]], burn_in)
-  expect_equal(out_2st_simb$input[[6]], n)
-  expect_equal(out_2st_simb$input[[7]], rep(n_t, n))
-  expect_equal(out_2st_simb$input[[8]], c("output_1", "output_2"))
+  expect_equal(out_2st_simb$input[[1]], "categorical")
+  expect_equal(out_2st_simb$input[[2]], m)
+  expect_equal(out_2st_simb$input[[3]], n_dep)
+  expect_equal(out_2st_simb$input[[4]], q_emiss)
+  expect_equal(out_2st_simb$input[[5]], J)
+  expect_equal(out_2st_simb$input[[6]], burn_in)
+  expect_equal(out_2st_simb$input[[7]], n)
+  expect_equal(out_2st_simb$input[[8]], rep(n_t, n))
+  expect_equal(out_2st_simb$input[[9]], c("output_1", "output_2"))
 })
 
 
@@ -294,4 +299,3 @@ test_that("output input", {
 
 
 
-
