@@ -12,8 +12,8 @@ q_emiss <- c(4,2)
 gamma <- matrix(c(0.8, 0.1, 0.1,
                   0.2, 0.6, 0.2,
                   0.1, 0.2, 0.7), ncol = m, byrow = TRUE)
-emiss_distr <- list(matrix(c(0.5, 0.5, 0.0, 0.0,
-                             0.1, 0.1, 0.8, 0.0,
+emiss_distr <- list(matrix(c(0.45, 0.45, 0.05, 0.05,
+                             0.1, 0.05, 0.8, 0.05,
                              0.1, 0.1, 0.2, 0.6), nrow = m, ncol = q_emiss[1], byrow = TRUE),
                     matrix(c(0.7, 0.3,
                              0.9, 0.1,
@@ -46,10 +46,8 @@ test_that("expected errors viterbi", {
 
 test_that("output viterbi", {
   states1 <- vit_mHMM(out_2st_simb, s_data = data_sim$obs)
-  expect_equal(dim(states1), c(n_t, n))
-  expect_equal(sort(unique(states1[,1])), c(1:m))
-  expect_equal(sort(unique(states1[,n])), c(1:m))
-  expect_equal(sum(states1[,2]), 197)
-  expect_equal(sum(states1[2,]), 21)
+  expect_equal(dim(states1), c(n_t * n, 2))
+  expect_equal(sort(unique(states1[,2])), c(1:m))
+  expect_equal(sum(states1[,2]), 1890)
 })
 
